window#osd {
  border-radius: 999px;
  border: none;
  background: alpha(@theme_bg_color, 0.8); }
  window#osd #container {
    margin: 16px; }
  window#osd image,
  window#osd label {
    color: @theme_fg_color; }
  window#osd progressbar:disabled,
  window#osd image:disabled {
    opacity: 0.5; }
  window#osd progressbar,
  window#osd segmentedprogress {
    min-height: 6px;
    border-radius: 999px;
    background: transparent;
    border: none; }
  window#osd trough,
  window#osd segment {
    min-height: inherit;
    border-radius: inherit;
    border: none;
    background: alpha(@theme_fg_color, 0.5); }
  window#osd progress,
  window#osd segment.active {
    min-height: inherit;
    border-radius: inherit;
    border: none;
    background: @theme_fg_color; }
  window#osd segment {
    margin-left: 8px; }
    window#osd segment:first-child {
      margin-left: 0; }
